@@ -7,8 +7,8 @@ from fastapi.middleware.cors import CORSMiddleware
 import prometheus_client as pc
 from .ctx import Ctx
 
-c = pc.Counter('nbapi_request_count', 'Count the total number of incoming request', ['path', 'status_code', 'cid'])
-g = pc.Gauge('nbapi_request_duration', 'Gauge the duration of incoming request', ['path', 'status_code', 'cid'])
+c = pc.Counter('nbapis_request_count', 'Count the total number of incoming request', ['label', 'status_code', 'cid', 'kid'])
+g = pc.Gauge('nbapis_request_duration', 'Gauge the duration of incoming request', ['label', 'status_code', 'cid', 'kid'])
 
 
 class AuthError(Exception):
@@ -31,8 +31,8 @@ class NBApi(FastAPI):
             ts = time.time()
             request.state.ctx = Ctx(auth=request.headers.get('authorization'))
             resp = await call_next(request)
-            c.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.ctx.cid).inc()
-            g.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.ctx.cid).set(time.time() - ts)
+            c.labels(label=request.state.ctx.label, status_code=resp.status_code, cid=request.state.ctx.cid, kid=request.state.ctx.kid).inc()
+            g.labels(label=request.state.ctx.label, status_code=resp.status_code, cid=request.state.ctx.cid, kid=request.state.ctx.kid).set(time.time() - ts)
             return resp
 
         self.middleware('http')(http_middleware)
