@@ -10,11 +10,13 @@ _loggers = {
 }
 
 
-class Ctx:
+class Ctx(object):
     def __init__(self, auth: str = '', state: typing.Dict = {}):
-        super().__setattr__("_state", state)
+        self.__setattr__('_state', state)
         self.uid = str(uuid.uuid4())
         self.cid = 'unknown'
+        self.kid = 'unknown'
+        self.label = 'unknown'
         self.auth = auth
 
     def __setattr__(self, key: typing.Any, value: typing.Any) -> None:
